Assystent domowy
=================================================================================

Platforma automatyki domowej typu OpenSource, która na pierwszym miejscu stawia kontrolę lokalną i prywatność.


|screenshot-states|


.. |screenshot-states| image:: https://raw.github.com/sviete/AIS-home-assistant/master/docs/screenshots.png
   :target: https://www.ai-speaker.com
